@@ -109,11 +109,13 @@ class BackupManager():
         self.config.locked = True
 
     def saveConfig(self) -> None:
+        """Saves config as JSON file"""
         writeJson(os.path.join(self.config.source, self.config.config_dir, "config.json"), vars(self.config))
         print(self.log.colourString(getString("Config saved"), "G"))
         sys.exit(0)
 
     def loadConfig(self) -> None:
+        """Load config from JSON file (internal use only during init)"""
         # will probably raise an exception and crash (safely) if the configuration is not valid json
         current_source = self.config.source
         config_dir = os.path.abspath(os.path.join(self.config.source, self.config.config_dir, "config.json"))
@@ -126,11 +128,64 @@ class BackupManager():
             sys.exit(1)
 
     def abortRun(self) -> int:
+        """Write log for aborted run and return 1 (internal use only)"""
         self.log.append([getString("### ABORTED ###")])
         self.log.writeLog("database.aborted.json")
         print(self.log.colourString(getString("Run aborted"), "Y"))
         return 1
 
+    def _internalTests(self, transfer_lists: TransferLists) -> None:
+        if self.backup_time == "000000-0000":
+            testConsistency(self.source.getDicts(), self.source.getSets(),
+                            self.dest.getDicts(), self.dest.getSets(),
+                            transfer_lists.getSets(),
+                            self.source.compareDb(self.source.dict_prev, set(), False, False, True),
+                            self.dest.compareDb(self.dest.dict_prev, set(), False, False, True),
+                            self.source.compareDb(self.source.dict_prev, set(), True, False, True),
+                            self.dest.compareDb(self.dest.dict_prev, set(), True, False, True))
+
+    def _scanDirectories(self) -> bool:
+        # init FileScanner and load previous scan data if available
+        self.source = FileScanner(self.config.source, self.config.source_unique_id,
+                              self.config.dest, self.config, self.gui)
+        self.dest = FileScanner(self.config.dest, self.config.dest_unique_id,
+                            self.config.source, self.config, self.gui)
+        dest_database_load_success = False
+        self.source.loadDatabase()
+        self.dest.loadDatabase(self.config.use_cold_storage)
+        if self.dest.dict_prev != {}:
+            dest_database_load_success = True
+        # scan directories (also calculates CRC if enabled) (didn't parallelize scans to prevent excess vibration of adjacent consumer grade disks and keep status bars simple)
+        try:
+            self.log.colourPrint(getString("Scanning files on source:\n%s") % (self.config.source), "B")
+            self.source.scanDir(self.config.stdout_status_bar)
+            if not self.config.use_cold_storage:
+                if self.config.source != self.config.dest:
+                    self.log.colourPrint(getString("Scanning files on destination:\n%s") % (self.config.dest), "B")
+                    self.dest.scanDir(self.config.stdout_status_bar)
+                else:
+                    self.dest = self.source
+        except Exception as e:
+            self.log.colourPrint(getString("Error encountered during scan: ") + str(e.args[0]), "R")
+            self.log.colourPrint(getString("BackuPy will now exit without taking any action."), "R")
+            sys.exit(1)
+        # update log manager to reference the same source and dest
+        self.log.source, self.log.dest = self.source, self.dest
+        return dest_database_load_success
+
+    def _compareDirectories(self):
+        # compare directories (should be relatively fast, all the read operations are done during scan)
+        transfer_lists = None
+        if not self.config.scan_only:
+            self.log.colourPrint(getString("Comparing directories..."), "B")
+            transfer_lists = TransferLists(self.source.compareOtherScanner(self.dest, self.config.nomoves))
+            if self.config.main_mode == "sync":
+                transfer_lists.updateSyncMovedDirection(self.dest)
+                if self.config.sync_propagate_deletions:
+                    transfer_lists.propagateSyncDeletions(self.source, self.dest)
+            transfer_lists.freeze()
+        return transfer_lists
+
     def _databaseAndCorruptionCheck(self, dest_database_load_success: bool) -> bool:
         # get databases
         source_dict, source_prev = self.source.getDicts()
@@ -319,41 +374,9 @@ class BackupManager():
             print(self.log.colourString(getString("Dry Run"), "V"))
         else:
             simulation_msg = ""
-        # init FileScanner and load previous scan data if available
-        self.source = FileScanner(self.config.source, self.config.source_unique_id,
-                              self.config.dest, self.config, self.gui)
-        self.dest = FileScanner(self.config.dest, self.config.dest_unique_id,
-                            self.config.source, self.config, self.gui)
-        dest_database_load_success = False
-        self.source.loadDatabase()
-        self.dest.loadDatabase(self.config.use_cold_storage)
-        if self.dest.dict_prev != {}:
-            dest_database_load_success = True
-        # scan directories (also calculates CRC if enabled) (didn't parallelize scans to prevent excess vibration of adjacent consumer grade disks and keep status bars simple)
-        try:
-            self.log.colourPrint(getString("Scanning files on source:\n%s") % (self.config.source), "B")
-            self.source.scanDir(self.config.stdout_status_bar)
-            if not self.config.use_cold_storage:
-                if self.config.source != self.config.dest:
-                    self.log.colourPrint(getString("Scanning files on destination:\n%s") % (self.config.dest), "B")
-                    self.dest.scanDir(self.config.stdout_status_bar)
-                else:
-                    self.dest = self.source
-        except Exception as e:
-            self.log.colourPrint(getString("Error encountered during scan: ") + str(e.args[0]), "R")
-            self.log.colourPrint(getString("BackuPy will now exit without taking any action."), "R")
-            return 1
-        # update log manager to reference the same source and dest
-        self.log.source, self.log.dest = self.source, self.dest
-        # compare directories (should be relatively fast, all the read operations are done during scan)
-        if not self.config.scan_only:
-            self.log.colourPrint(getString("Comparing directories..."), "B")
-            transfer_lists = TransferLists(self.source.compareOtherScanner(self.dest, self.config.nomoves))
-            if self.config.main_mode == "sync":
-                transfer_lists.updateSyncMovedDirection(self.dest)
-                if self.config.sync_propagate_deletions:
-                    transfer_lists.propagateSyncDeletions(self.source, self.dest)
-            transfer_lists.freeze()
+        # scan and compare directories
+        dest_database_load_success = self._scanDirectories()
+        transfer_lists = self._compareDirectories()
         # check for database conflicts or corruption
         detected_database_conflicts_or_corruption = self._databaseAndCorruptionCheck(dest_database_load_success)
         if self.config.quit_on_db_conflict and detected_database_conflicts_or_corruption:
@@ -370,14 +393,7 @@ class BackupManager():
         # print differences between source and dest
         self._printAndLogCompareDiffSummary(transfer_lists)
         # consistency checks used for testing and debugging
-        if self.backup_time == "000000-0000":
-            testConsistency(self.source.getDicts(), self.source.getSets(),
-                            self.dest.getDicts(), self.dest.getSets(),
-                            transfer_lists.getSets(),
-                            self.source.compareDb(self.source.dict_prev, set(), False, False, True),
-                            self.dest.compareDb(self.dest.dict_prev, set(), False, False, True),
-                            self.source.compareDb(self.source.dict_prev, set(), True, False, True),
-                            self.dest.compareDb(self.dest.dict_prev, set(), True, False, True))
+        self._internalTests(transfer_lists)
         # exit if directories already match
         if transfer_lists.isEmpty():
             print(self.log.colourString(getString("Directories already match, completed!"), "G"))
